@@ -2,6 +2,8 @@ import datetime
 from pprint import pprint
 import colorful as col
 from .start_up import URLS
+from .repl import prompt_session as ps
+from .repl import msgs_completer, com_completer
 from .network import req_get, req_post, req_put, req_delete
 from dataclasses import dataclass
 
@@ -20,8 +22,9 @@ class Contact:
 
 
 async def init_contacts():
+    global online
     json_resp = await req_get(
-        URLS["CONTACTS"],
+        URLS.contacts,
         topic="get_contacts",
     )
     for c in json_resp:
@@ -39,6 +42,12 @@ async def init_contacts():
         )
         all_contacts[c["contactId"]] = contact
         all_contacts_by_alias[alias_or_name] = contact
+        if contact.is_online:
+            online += 1
+    msgs_completer.extend(all_contacts_by_alias.keys())
+    msgs_completer.sort()
+    com_completer.extend(all_contacts_by_alias.keys())
+    com_completer.sort()
 
 
 async def show_contacts(detailed=None):
@@ -52,13 +61,15 @@ async def show_contacts(detailed=None):
         reverse=True
     )
     for contact in contacts_by_last_act:
-        online = col.bold_chartreuse("online") if contact.is_online else ""
+        contact_online = col.bold_chartreuse("online") if contact.is_online else ""
         unread_count = contact.unread_msgs if contact.unread_msgs else ''
         last_act = datetime.datetime.fromtimestamp(contact.last_activity / 1000).strftime('%Y-%m-%d %H:%M')
         if detailed:
-            print(f"{contact.cid:4} {last_act}: {contact.alias} {online} {col.bold_orange(unread_count)}")
+            verified = col.bold_chartreuse("V") if contact.verified else col.bold_coral("X")
+            print(f"{contact.cid:4} {verified} {last_act} {contact.unread_msgs:2} {contact.unread_count:2}: "
+                  f"{contact.alias} {contact_online} {col.bold_orange(unread_count)}")
         else:
-            print(f"    {contact.alias} {online} {col.bold_orange(unread_count)}")
+            print(f"    {contact.alias} {contact_online} {col.bold_orange(unread_count)}")
 
 
 async def show_contacts_detailed():
@@ -68,10 +79,15 @@ async def show_contacts_detailed():
     await show_contacts(detailed=True)
 
 
-async def show_contact_info(contact_str):
+async def show_contact_info(contact_str=None):
     """
     shows contact info
     """
+    if not contact_str:
+        print("not contact was specified")
+        contact_str = await ps.prompt_async("please specify contact:")
+        print(f"now got: {contact_str}")
+        return
     contact = await get_contact_id_by_alias(contact_str)
     if not contact:
         print(f"contact {contact_str} not found")
@@ -84,7 +100,7 @@ async def show_raw_contacts_info():
     shows raw contacts info
     """
     json_resp = await req_get(
-        URLS["CONTACTS"],
+        URLS.contacts,
         topic="get_contacts",
     )
     for c in json_resp:
@@ -98,7 +114,7 @@ async def get_contact_id_by_alias(alias):
 
 async def get_pending_contacts():
     json_resp = await req_get(
-        URLS["CONTACTS_PENDING"],
+        URLS.contacts_pending,
         topic="get_pending_contacts",
     )
     return json_resp
@@ -136,13 +152,13 @@ async def remove_pending_contact(contact_str):
     }
     pprint(remove_contact)
     json_resp = await req_delete(
-        URLS["CONTACTS_PENDING"],
+        URLS.contacts_pending,
         topic="get_pending_contacts",
         params=remove_contact,
     )
     import httpx
     httpx.delete(
-        URLS["CONTACTS_PENDING"],
+        URLS.contacts_pending,
     )
     return json_resp
 
@@ -156,7 +172,7 @@ async def add_contact(briar_link, alias):
         "alias": alias,
     }
     json_resp = await req_post(
-        url=URLS["CONTACTS_ADD_PENDING"],
+        url=URLS.contacts_pending,
         json_data=add_contact,
         topic=f"add_contact {alias} - {briar_link}",
     )
@@ -172,7 +188,7 @@ async def rename_contact(contact_str, new_alias):
         print(f"contact {contact_str} not found")
         return
     json_resp = await req_put(
-        url=f"{URLS['CONTACTS']}/{contact.cid}/alias",
+        url=f"{URLS.contacts}/{contact.cid}/alias",
         json_data={"alias": new_alias},
         topic=f"renames_contact {contact_str} to {new_alias}",
     )
@@ -190,7 +206,7 @@ async def remove_contact(contact_str):
         print(f"contact {contact_str} not found")
         return
     json_resp = await req_delete(
-        url=f"{URLS['CONTACTS']}/{contact.cid}",
+        url=f"{URLS.contacts}/{contact.cid}",
         topic=f"remove_contact {contact.cid}",
     )
     if json_resp:
@@ -200,7 +216,7 @@ async def remove_contact(contact_str):
 
 async def get_own_briar_link():
     json_resp = await req_get(
-        url=URLS["ADD_LINK"],
+        url=URLS.link,
         topic="get_own_briar_link",
     )
     return json_resp
@@ -217,3 +233,4 @@ async def show_own_briar_link():
 all_contacts          = {}
 all_contacts_by_alias = {}
 current_contact = {"id": 0, "alias":""}
+online = 0
