@@ -10,7 +10,7 @@ from .network import req_get, req_post
 
 async def send(contact_id, text):
     json_resp = await req_post(
-        url=URLS["MSGS"] + str(contact_id),
+        url=URLS.msgs + str(contact_id),
         json_data={'text': text},
         topic=f"send_message to {contact_id}"
     )
@@ -19,9 +19,10 @@ async def send(contact_id, text):
 
 async def get_history(contact_id):
     json_resp = await req_get(
-        url=URLS["MSGS"] + str(contact_id),
+        url=URLS.msgs + str(contact_id),
         topic="get_history"
     )
+    # pprint(json_resp) # messgaes debug
     return json_resp
 
 
@@ -47,13 +48,18 @@ async def print_message(message):
     correspondent = cont.current_contact["alias"] or ""
     prefix = 'me' if message['local'] else f'{correspondent}'
     time = await get_time(message['timestamp'])
-    if 'text' in message:
-        time_stamp = col.grey60(time)
-        print(f"{time_stamp} {prefix}:\n    {message['text']}\n")
+    msgs_type = message["type"]
+    if msgs_type == "PrivateMessage":
+        if 'text' in message:
+            # time_stamp = col.grey60(time)
+            time_stamp = time
+            print(f"{time_stamp} {prefix}:\n    {message['text']}\n")
 
-    is_read = message['read']
-    if not is_read:
-        await mark_message_as_read(message)
+        is_read = message['read']
+        if not is_read:
+            await mark_message_as_read(message)
+    else:
+        print(col.coral(f"unsupported message type: {msgs_type}\n"))
 
 
 async def get_time(msg_time):
@@ -66,9 +72,9 @@ async def mark_message_as_read(message):
     msg_id = message["id"]
     msg_read = {"messageId": msg_id}
     resp = await req_post(
-        url=URLS["MSGS"] + str(message['contactId']) + "/read",
+        url=URLS.msgs + str(message['contactId']) + "/read",
         json_data=msg_read,
-        topic="get_history",
+        topic="mark_message_as_read",
     )
     # print(resp)
 
