@@ -5,7 +5,10 @@ from .start_up import AUTH
 async def check_response(resp, topic):
     status = resp.status_code
     if status != 200:
-        print(f"{topic or ''}request not successful: {status}")
+        print(f"{topic or ''} request not successful: {status}")
+        #if status == 500:
+        #    print(topic)
+        #    print(resp)
     else:
         return True
 
@@ -21,6 +24,13 @@ async def req_get(url, topic):
             return resp.json()
 
 
+async def probe_req_get(url, topic):
+    try:
+        return await req_get(url, topic)
+    except httpx.ConnectError:
+        return {"error": "httpx.ConnectError"}
+
+
 async def req_post(url, json_data, topic=None):
     async with httpx.AsyncClient() as client:
         resp = await client.post(
